@@ -11,6 +11,7 @@ UNIVERSE_PATH = '/universe'
 RANK_PATH = '/rank'
 DATA_PATH = '/data'
 RANK_RANKS_PATH = '/rank/ranks'
+RANK_PERF_PATH = '/rank/performance'
 DATA_UNIVERSE_PATH = '/data/universe'
 
 
@@ -81,23 +82,22 @@ class Client(object):
             verify=self._verify_requests,
             timeout=30
         )
-        if resp:
-            if resp.status_code == 200:
-                self._session.headers.update({'Authorization': f'Bearer {resp.text}'})
+        if resp.status_code == 200:
+            self._session.headers.update({'Authorization': f'Bearer {resp.text}'})
+        else:
+            if resp.status_code == 406:
+                message = 'user account inactive'
+            elif resp.status_code == 402:
+                message = 'paying subscription required'
+            elif resp.status_code == 401:
+                message = 'invalid id/key combination or key inactive'
+            elif resp.status_code == 400:
+                message = 'invalid key'
             else:
-                if resp.status_code == 406:
-                    message = 'user account inactive'
-                elif resp.status_code == 402:
-                    message = 'paying subscription required'
-                elif resp.status_code == 401:
-                    message = 'invalid id/key combination or key inactive'
-                elif resp.status_code == 400:
-                    message = 'invalid key'
-                else:
-                    message = resp.text
-                if message:
-                    message = ': ' + message
-                raise ClientException(f'API authentication failed{message}', resp=resp)
+                message = resp.text
+            if message:
+                message = ': ' + message
+            raise ClientException(f'API authentication failed{message}', resp=resp)
 
     def _req_with_auth_fallback(self, *, name: str, url: str, params, stop: bool = False):
         """
@@ -206,7 +206,7 @@ class Client(object):
 
     def data_universe(self, params: dict):
         """
-        Data
+        Universe data
         :param params:
         :return:
         """
@@ -218,7 +218,7 @@ class Client(object):
 
     def rank_ranks(self, params: dict):
         """
-        Data
+        Ranking system ranks
         :param params:
         :return:
         """
@@ -228,6 +228,18 @@ class Client(object):
             params=params
         ).json()
 
+    def rank_perf(self, params: dict):
+        """
+        Ranking system performance
+        :param params:
+        :return:
+        """
+        return self._req_with_auth_fallback(
+            name='data',
+            url=self._endpoint + RANK_PERF_PATH,
+            params=params
+        ).json()
+
     def get_api_id(self):
         return self._api_id
 
